@@ -1,5 +1,6 @@
 import os
 import subprocess
+import uuid
 
 import nest_asyncio
 import uvicorn
@@ -20,13 +21,23 @@ CODESERVER_VERSION = "3.7.4"
 
 class ColabCode:
     def __init__(
-        self, port=10000, password=None, authtoken=None, mount_drive=False, code=True
+        self,
+        port=10000,
+        password=None,
+        authtoken=None,
+        mount_drive=False,
+        code=True,
+        lab=False,
     ):
         self.port = port
         self.password = password
         self.authtoken = authtoken
         self._mount = mount_drive
         self._code = code
+        self._lab = lab
+        if self._lab:
+            self._start_server()
+            self._run_lab()
         if self._code:
             self._install_code()
             self._install_extensions()
@@ -61,6 +72,28 @@ class ColabCode:
         else:
             print(f"Public URL: {url}")
 
+    def _run_lab(self):
+        token = str(uuid.uuid1())
+        print(f"Jupyter lab token: {token}")
+        base_cmd = "jupyter-lab --ip='localhost' --allow-root --ServerApp.allow_remote_access=True --no-browser"
+        os.system(f"fuser -n tcp -k {self.port}")
+        if self._mount and colab_env:
+            drive.mount("/content/drive")
+        if self.password:
+            lab_cmd = f" --ServerApp.token='{token}' --ServerApp.password='{self.password}' --port {self.port}"
+        else:
+            lab_cmd = f" --ServerApp.token='{token}' --ServerApp.password='' --port {self.port}"
+        lab_cmd = base_cmd + lab_cmd
+        with subprocess.Popen(
+            [lab_cmd],
+            shell=True,
+            stdout=subprocess.PIPE,
+            bufsize=1,
+            universal_newlines=True,
+        ) as proc:
+            for line in proc.stdout:
+                print(line, end="")
+
     def _run_code(self):
         os.system(f"fuser -n tcp -k {self.port}")
         if self._mount and colab_env:
